<?php

namespace Bydedi\Tracking\Google;

/**
 * Class TrustedStores
 * @package Bydedi\Tracking\Google
 */
class TrustedStores
{
    /**
     * @var bool
     */
    protected static $isInit = false;

    /**
     * @var array|null $config
     */
    protected static $config = null;

    /**
     * @param array $config
     */
    public static function init($config = array())
    {
        $defaults = [
            'badge_position' => 'BOTTOM_RIGHT',
            'language_code' => 'fr',
            'country_code' => 'FR',
            'currency' => 'EUR',
            'locale' => 'fr_FR',
            'has_preorder' => 'N',
            'has_digital' => 'N',
            'extra_shipping_delay' => (60*60*24)
        ];

        $config = array_filter($config, function ($d) {
                return (isset($d) && $d != '');
            }) + array_filter($defaults, function ($d) {
                return (isset($d) && $d != '');
            });

        self::$config = $config;
    }

    /**
     * Check if it's initialized.
     * If not trigger a warning error
     */
    protected static function triggerErrorIfNotInit()
    {
        if (is_null(self::$config)) {
            trigger_error("Google TrustedStores n'est pas initialisé", E_USER_WARNING);
        }
    }

    public static function common($param)
    {
        if (self::$isInit == true) {
            return "";
        }

        self::$isInit = true;

        $tracker = '
                <script type="text/javascript">
                var gts = gts || [];
                gts.push(["id", "'.self::$config['id'].'"]);
                gts.push(["badge_position", "'.self::$config['badge_position'].'"]);
                //gts.push(["badge_container", "googleTrusted"]);
                gts.push(["locale", "'.self::$config['locale'].'"]);';
        if (!empty(self::$config['google_shopping_id'])) {
            $tracker .= 'gts.push(["google_base_subaccount_id", "' . self::$config['google_shopping_id'] . '"]);';
        }
        $tracker.= '</script>';
        $tracker.= '
                <script type="text/javascript">(function() {
                var gts = document.createElement("script");
                gts.type = "text/javascript";
                gts.async = true;
                gts.src = "https://www.googlecommerce.com/trustedstores/api/js";
                var s = document.getElementsByTagName("script")[0];
                s.parentNode.insertBefore(gts, s);
                })();
                </script>
                <div id="googleTrusted"></div>';


        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position'], $tracker);
        }
    }

    public static function getVisites($param = array())
    {
        self::common($param);
    }

    public static function paiement($param = array())
    {

        self::common($param);

        $out = '<!-- START Google Marchands de confiance Order -->
                <div id="gts-order" style="display:none;" translate="no">
                  <!-- start order and merchant information -->
                  <span id="gts-o-id">' . $param['extra']['commande_id'] . '</span>
                  <span id="gts-o-domain">' . $_SERVER['HTTP_HOST'] . '</span>
                  <span id="gts-o-email">' . $param['extra']['client_email'] . '</span>
                  <span id="gts-o-country">' . $param['extra']['livraison_pays_code'] . '</span>
                  <span id="gts-o-currency">' . self::$config['currency'] . '</span>
                  <span id="gts-o-total">' . $param['extra']['commande_total_ttc'] . '</span>
                  <span id="gts-o-discounts">0</span>
                  <span id="gts-o-shipping-total">' . $param['extra']['commande_total_ttc'] . '</span>
                  <span id="gts-o-tax-total">' . $param['extra']['commande_total_taxe'] . '</span>';

        $out.= '<span id="gts-o-est-ship-date">'.date('Y-m-d',time()+self::$config['extra_shipping_delay']+(60*60*24*$param['extra']['commande_livraison_delai'])).'</span>';
        // <span id="gts-o-est-delivery-date">ORDER_EST_DELIVERY_DATE</span>
        $out.= '<span id="gts-o-has-preorder">' . self::$config['has_preorder'] . '</span>
                  <span id="gts-o-has-digital">' . self::$config['has_digital'] . '</span>
                  <!-- end order and merchant information -->

                  <!-- start repeated item specific information -->
                  <!-- item example: this area repeated for each item in the order -->';
        foreach ($param['extra']['produits'] as $produit) {
            $out .= '    <span class="gts-item">
                                <span class="gts-i-name">' . $produit['produit_nom'] . '</span>
                                <span class="gts-i-price">' . $produit['prix_ttc'] . '</span>
                                <span class="gts-i-quantity">' . $produit['qte'] . '</span>
                                <span class="gts-i-prodsearch-id">'.(!empty($produit['produit_id']) ? $produit['produit_id'] : "").'</span>
                                <span class="gts-i-prodsearch-store-id">'.self::$config['google_shopping_id'].'</span>
                                <span class="gts-i-prodsearch-country">'.self::$config['country_code'].'</span>
                                <span class="gts-i-prodsearch-language">'.self::$config['language_code'].'</span>
                            </span>';
        }
        $out .= '  <!-- end item 1 example -->
                  <!-- end repeated item specific information -->

                </div>
                <!-- END Google Marchands de confiance Order -->';



        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_paiement'], $out);
        }
    }
}
